import * as colorNames from 'color-name';
import Color, { ColorValue } from './color.types.js';
/**
 * CSS color names as defined by the W3C
 *
 * @see https://github.com/maranomynet/es-in-css/tree/v0.7#color-helper
 */
export type ColorName = keyof typeof colorNames;
/**
 * An object that represetns a CSS color value. Can be used in CSS, but also
 * omes with useful manipulation mhethods.
 *
 * @see https://github.com/maranomynet/es-in-css/tree/v0.7#color-helper
 */
export type { ColorValue } from './color.types.js';
/**
 * Creates `ColorValue` instances that can be used in CSS, but also come with
 * useful manipulation mhethods.
 *
 * @see https://github.com/maranomynet/es-in-css/tree/v0.7#color-helper
 */
export declare const color: typeof Color & {
    fromName(colorName: ColorName): ColorValue;
};
/**
 * Create a `ColorValue` instance from a numeric RGB/RGBA color-channel values.
 *
 * @see https://github.com/maranomynet/es-in-css/tree/v0.7#color-helper
 */
export declare const rgb: {
    (...val: Array<number>): ColorValue;
    (color: string | number | ColorValue | ArrayLike<number> | {
        [key: string]: any;
    }): ColorValue;
};
/**
 * Create a `ColorValue` instance from a numeric HSL/HSLA color-channel values.
 *
 * @see https://github.com/maranomynet/es-in-css/tree/v0.7#color-helper
 */
export declare const hsl: {
    (...val: Array<number>): ColorValue;
    (color: string | number | ColorValue | ArrayLike<number> | {
        [key: string]: any;
    }): ColorValue;
};
