"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.hsl = exports.rgb = exports.color = void 0;
const color_1 = __importDefault(require("color"));
// ---------------------------------------------------------------------------
/**
 * Creates `ColorValue` instances that can be used in CSS, but also come with
 * useful manipulation mhethods.
 *
 * @see https://github.com/maranomynet/es-in-css/tree/v0.7#color-helper
 */
/*#__NO_SIDE_EFFECTS__*/
exports.color = color_1.default;
// eslint-disable-next-line @typescript-eslint/no-unsafe-member-access
exports.color.prototype.getName = exports.color.prototype.toString;
// Patch color's lossy hex method.
// See: https://github.com/Qix-/color/issues/243
const oldHex = exports.color.prototype.hex;
exports.color.prototype.hex = function (value) {
    if (arguments.length > 0) {
        return new exports.color(value);
    }
    // @ts-expect-error  (@types/color don't fully match color's actual implementation)
    // eslint-disable-next-line @typescript-eslint/no-unsafe-member-access
    return this.valpha === 1 ? oldHex.call(this) : this.hexa();
};
// ---------------------------------------------------------------------------
/**
 * Create a `ColorValue` instance from a numeric RGB/RGBA color-channel values.
 *
 * @see https://github.com/maranomynet/es-in-css/tree/v0.7#color-helper
 */
/*#__NO_SIDE_EFFECTS__*/
exports.rgb = exports.color.rgb;
/**
 * Create a `ColorValue` instance from a numeric HSL/HSLA color-channel values.
 *
 * @see https://github.com/maranomynet/es-in-css/tree/v0.7#color-helper
 */
/*#__NO_SIDE_EFFECTS__*/
exports.hsl = exports.color.hsl;
/**
 * Type-safe name to color mapper. Alias for `color(colorName)`
 *
 * @see https://github.com/maranomynet/es-in-css/tree/v0.7#color-helper
 */
/*#__NO_SIDE_EFFECTS__*/
exports.color.fromName = (colorName) => (0, exports.color)(colorName);
