#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const glob_1 = require("glob");
const compiler_js_1 = require("../compiler.js");
const program = new commander_1.Command('es-in-css');
program
    .arguments('<inputglob>')
    .option('-d, --outdir <path>', 'Output directory')
    .option('-b, --outbase <path>', 'Specific common parent directory for the input glob file list — auto-detected by default.')
    .option('-e, --ext <file-extension>', 'Custom file extension for the output files. Defaults to `.css`')
    .option('-m, --minify', 'Minify the CSS output. Uses cssnano with its "default" preset.')
    .option('-p, --prettify [configFilePath]', 'Runs the result CSS through Prettier. Accepts optional `configFilePath`, but defaults to resolving `.prettierrc` of `--outdir` or the current directory. Ignored if mixed with `--minify`.')
    .option('-n, --no-nested', 'Disables the SCSS-like selector nesting behavior provided by the postcss-nested plugin.');
program.parse();
const inputGlob = program.args[0];
const options = program.opts();
// ---------------------------------------------------------------------------
const inputFiles = inputGlob ? (0, glob_1.sync)(inputGlob) : [];
if (!inputFiles.length) {
    console.info(`No files found matching '${inputGlob}'`);
    process.exit();
}
(0, compiler_js_1.compileCSS)(inputFiles, options).catch((e) => {
    const message = e instanceof Error ? e.message : String(e);
    console.warn('ERROR: ', message);
    process.exit(1);
});
